@@ -1,11 +1,14 @@
-from Foundation import *
+import objc
+from Foundation import NSObject
+from objc import super
 
-class Converter (NSObject):
+
+class Converter(NSObject):
     exchangeRate = objc.ivar.double()
     dollarsToConvert = objc.ivar.double()
 
     def init(self):
-        self = super(Converter, self).init()
+        self = super().init()
         self.exchangeRate = 3
         self.dollarsToConvert = 4
         return self
@@ -13,7 +16,7 @@ class Converter (NSObject):
     def amountInOtherCurrency(self):
         return self.dollarsToConvert * self.exchangeRate
 
+
 Converter.setKeys_triggerChangeNotificationsForDependentKey_(
-    [u"dollarsToConvert", u"exchangeRate"],
-    u"amountInOtherCurrency"
+    ["dollarsToConvert", "exchangeRate"], "amountInOtherCurrency"
 )
