@@ -1,10 +1,11 @@
+import objc
 from Foundation import NSObject
 from objc import super
-import objc
+
 
 class RPCMethod(NSObject):
     def initWithDocument_name_(self, aDocument, aName):
-        self = super(RPCMethod, self).init()
+        self = super().init()
         self.document = aDocument
         self.k_methodName = aName
         self.k_methodSignature = None
