@@ -53,7 +53,7 @@ class PyObjCMessageRunner(NSObject):
         """
         Designated initializer.
         """
-        self = super(PyObjCMessageRunner, self).init()
+        self = super().init()
         if not self:
             return None
 
@@ -142,7 +142,7 @@ class PyObjCAppHelperRunLoopStopper(NSObject):
     currentRunLoopStopper = classmethod(currentRunLoopStopper)
 
     def init(self):
-        self = super(PyObjCAppHelperRunLoopStopper, self).init()
+        self = super().init()
         self.shouldStop = False
         return self
 
@@ -334,11 +334,11 @@ def runEventLoop(
 
                     NSLog("%@", error_str)
                 elif not unexpectedErrorAlert():
-                    NSLog("%@", "An exception has occured:")
+                    NSLog("%@", "An exception has occurred:")
                     traceback.print_exc()
                     sys.exit(0)
                 else:
-                    NSLog("%@", "An exception has occured:")
+                    NSLog("%@", "An exception has occurred:")
                     traceback.print_exc()
             else:
                 break
